@@ -52,6 +52,9 @@ def find_ffmpeg() -> Optional[str]:
         "C:\\ProgramData\\chocolatey\\bin\\ffmpeg.exe",
         "C:\\Program Files\\ffmpeg\\bin\\ffmpeg.exe",
         "C:\\ffmpeg\\bin\\ffmpeg.exe",
+        "/usr/local/bin/ffmpeg",
+        "/opt/homebrew/bin/ffmpeg",
+        "/usr/bin/ffmpeg",
         "ffmpeg",
     ]
 
@@ -92,6 +95,9 @@ def find_ffprobe() -> Optional[str]:
         "C:\\ProgramData\\chocolatey\\bin\\ffprobe.exe",
         "C:\\Program Files\\ffmpeg\\bin\\ffprobe.exe",
         "C:\\ffmpeg\\bin\\ffprobe.exe",
+        "/usr/local/bin/ffprobe",
+        "/opt/homebrew/bin/ffprobe",
+        "/usr/bin/ffprobe",
         "ffprobe",
     ]
 
@@ -242,11 +248,29 @@ def run_timed_ffmpeg_command(
             if not line:
                 continue
 
-            sys.stderr.write(line)
-            sys.stderr.flush()
+            # Filter out excessive progress output, only show important lines
+            if any(
+                keyword in line.lower()
+                for keyword in [
+                    "error",
+                    "warning",
+                    "encoded successfully",
+                    "frame=",
+                    "time=",
+                    "size=",
+                    "bitrate=",
+                    "speed=",
+                ]
+            ):
+                sys.stderr.write(line)
+                sys.stderr.flush()
 
-            # Send FFmpeg output to reporter for GUI display
-            progress_reporter.log(line.strip())
+            # Send FFmpeg output to reporter for GUI display (filtered)
+            if any(
+                keyword in line.lower()
+                for keyword in ["error", "warning", "encoded successfully", "frame="]
+            ):
+                progress_reporter.log(line.strip())
 
             match = re.search(r"frame=\s*(\d+)", line)
             if match:
@@ -365,7 +389,11 @@ def build_video_commands(
             # Use a fast software encoder instead
             video_encoder_args = ["-c:v libx264", "-preset veryfast", "-crf 23"]
 
-    audio_parts = ["-c:a aac", f'"{output_file}"', "-loglevel info -stats -hide_banner"]
+    audio_parts = [
+        "-c:a aac",
+        f'"{output_file}"',
+        "-loglevel warning -stats -hide_banner",
+    ]
 
     full_command_parts = (
         global_parts + input_parts + output_parts + video_encoder_args + audio_parts
